@@ -6,7 +6,7 @@ import * as wasm from './reference_test_bg.wasm';
 * @returns {number}
 */
 export function add_u32(a, b) {
-    var ret = wasm.add_u32(a, b);
+    const ret = wasm.add_u32(a, b);
     return ret >>> 0;
 }
 
@@ -16,7 +16,7 @@ export function add_u32(a, b) {
 * @returns {number}
 */
 export function add_i32(a, b) {
-    var ret = wasm.add_i32(a, b);
+    const ret = wasm.add_i32(a, b);
     return ret;
 }
 
